@@ -1,8 +1,8 @@
 library(lubridate)
 
-data(sh)
-d1 <- make_track(sh, x_epsg31467, y_epsg31467)
-d2 <- sh %>% mutate(ts = as.POSIXct(ymd(day) + hms(time))) %>%  make_track(x_epsg31467, y_epsg31467, ts)
+data(deer)
+d1 <- make_track(deer, x_, y_)
+d2 <- deer %>%  make_track(x_, y_, t_)
 d2
 
 
@@ -16,3 +16,4 @@ test_that("Create steps", {
   expect_is(d1 %>% steps() %>% random_steps(), "random_steps")
   expect_is(d2 %>% steps() %>% random_steps(), "random_steps")
 })
+
